# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

import types

__config__ = pulumi.Config('ns1')


class _ExportableConfig(types.ModuleType):
    @property
    def apikey(self) -> Optional[str]:
        """
        The ns1 API key (required)
        """
        return __config__.get('apikey')

    @property
    def enable_ddi(self) -> Optional[bool]:
        """
        Deprecated, no longer in use
        """
        return __config__.get_bool('enableDdi')

    @property
    def endpoint(self) -> Optional[str]:
        """
        URL prefix (including version) for API calls
        """
        return __config__.get('endpoint')

    @property
    def ignore_ssl(self) -> Optional[bool]:
        """
        Don't validate server SSL/TLS certificate
        """
        return __config__.get_bool('ignoreSsl')

    @property
    def rate_limit_parallelism(self) -> Optional[int]:
        """
        Tune response to rate limits, see docs
        """
        return __config__.get_int('rateLimitParallelism')

    @property
    def retry_max(self) -> Optional[int]:
        """
        Maximum retries for 50x errors (-1 to disable)
        """
        return __config__.get_int('retryMax')

    @property
    def user_agent(self) -> Optional[str]:
        """
        User-Agent string to use in NS1 API requests
        """
        return __config__.get('userAgent')




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RecordArgs', 'Record']

@pulumi.input_type
class RecordArgs:
    def __init__(__self__, *,
                 domain: pulumi.Input[str],
                 type: pulumi.Input[str],
                 zone: pulumi.Input[str],
                 answers: Optional[pulumi.Input[Sequence[pulumi.Input['RecordAnswerArgs']]]] = None,
                 blocked_tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input['RecordFilterArgs']]]] = None,
                 link: Optional[pulumi.Input[str]] = None,
                 meta: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 override_ttl: Optional[pulumi.Input[bool]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input['RecordRegionArgs']]]] = None,
                 short_answers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 ttl: Optional[pulumi.Input[int]] = None,
                 use_client_subnet: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a Record resource.
        :param pulumi.Input[str] domain: The records' domain. Cannot have leading or trailing
               dots - see the example above and `FQDN formatting` below.
        :param pulumi.Input[str] type: The records' RR type.
        :param pulumi.Input[str] zone: The zone the record belongs to. Cannot have leading or
               trailing dots (".") - see the example above and `FQDN formatting` below.
        :param pulumi.Input[Sequence[pulumi.Input['RecordAnswerArgs']]] answers: One or more NS1 answers for the records' specified type.
               Answers are documented below.
        :param pulumi.Input[Sequence[pulumi.Input['RecordFilterArgs']]] filters: One or more NS1 filters for the record(order matters).
               Filters are documented below.
        :param pulumi.Input[str] link: The target record to link to. This means this record is a
               'linked' record, and it inherits all properties from its target.
        :param pulumi.Input[Sequence[pulumi.Input['RecordRegionArgs']]] regions: One or more "regions" for the record. These are really
               just groupings based on metadata, and are called "Answer Groups" in the NS1 UI,
               but remain `regions` here for legacy reasons. Regions are
               documented below. Please note the ordering requirement!
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: map of tags in the form of `"key" = "value"` where both key and value are strings
        :param pulumi.Input[int] ttl: The records' time to live (in seconds).
        :param pulumi.Input[bool] use_client_subnet: Whether to use EDNS client subnet data when
               available(in filter chain).
               * ` meta` - (Optional) meta is supported at the `record` level. Meta
               is documented below.
        """
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "zone", zone)
        if answers is not None:
            pulumi.set(__self__, "answers", answers)
        if blocked_tags is not None:
            pulumi.set(__self__, "blocked_tags", blocked_tags)
        if filters is not None:
            pulumi.set(__self__, "filters", filters)
        if link is not None:
            pulumi.set(__self__, "link", link)
        if meta is not None:
            pulumi.set(__self__, "meta", meta)
        if override_ttl is not None:
            pulumi.set(__self__, "override_ttl", override_ttl)
        if regions is not None:
            pulumi.set(__self__, "regions", regions)
        if short_answers is not None:
            warnings.warn("""short_answers will be deprecated in a future release. It is suggested to migrate to a regular \"answers\" block.""", DeprecationWarning)
            pulumi.log.warn("""short_answers is deprecated: short_answers will be deprecated in a future release. It is suggested to migrate to a regular \"answers\" block.""")
        if short_answers is not None:
            pulumi.set(__self__, "short_answers", short_answers)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if ttl is not None:
            pulumi.set(__self__, "ttl", ttl)
        if use_client_subnet is not None:
            pulumi.set(__self__, "use_client_subnet", use_client_subnet)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Input[str]:
        """
        The records' domain. Cannot have leading or trailing
        dots - see the example above and `FQDN formatting` below.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[str]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        The records' RR type.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def zone(self) -> pulumi.Input[str]:
        """
        The zone the record belongs to. Cannot have leading or
        trailing dots (".") - see the example above and `FQDN formatting` below.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: pulumi.Input[str]):
        pulumi.set(self, "zone", value)

    @property
    @pulumi.getter
    def answers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RecordAnswerArgs']]]]:
        """
        One or more NS1 answers for the records' specified type.
        Answers are documented below.
        """
        return pulumi.get(self, "answers")

    @answers.setter
    def answers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RecordAnswerArgs']]]]):
        pulumi.set(self, "answers", value)

    @property
    @pulumi.getter(name="blockedTags")
    def blocked_tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "blocked_tags")

    @blocked_tags.setter
    def blocked_tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "blocked_tags", value)

    @property
    @pulumi.getter
    def filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RecordFilterArgs']]]]:
        """
        One or more NS1 filters for the record(order matters).
        Filters are documented below.
        """
        return pulumi.get(self, "filters")

    @filters.setter
    def filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RecordFilterArgs']]]]):
        pulumi.set(self, "filters", value)

    @property
    @pulumi.getter
    def link(self) -> Optional[pulumi.Input[str]]:
        """
        The target record to link to. This means this record is a
        'linked' record, and it inherits all properties from its target.
        """
        return pulumi.get(self, "link")

    @link.setter
    def link(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "link", value)

    @property
    @pulumi.getter
    def meta(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        return pulumi.get(self, "meta")

    @meta.setter
    def meta(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "meta", value)

    @property
    @pulumi.getter(name="overrideTtl")
    def override_ttl(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "override_ttl")

    @override_ttl.setter
    def override_ttl(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "override_ttl", value)

    @property
    @pulumi.getter
    def regions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RecordRegionArgs']]]]:
        """
        One or more "regions" for the record. These are really
        just groupings based on metadata, and are called "Answer Groups" in the NS1 UI,
        but remain `regions` here for legacy reasons. Regions are
        documented below. Please note the ordering requirement!
        """
        return pulumi.get(self, "regions")

    @regions.setter
    def regions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RecordRegionArgs']]]]):
        pulumi.set(self, "regions", value)

    @property
    @pulumi.getter(name="shortAnswers")
    @_utilities.deprecated("""short_answers will be deprecated in a future release. It is suggested to migrate to a regular \"answers\" block.""")
    def short_answers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "short_answers")

    @short_answers.setter
    def short_answers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "short_answers", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        map of tags in the form of `"key" = "value"` where both key and value are strings
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def ttl(self) -> Optional[pulumi.Input[int]]:
        """
        The records' time to live (in seconds).
        """
        return pulumi.get(self, "ttl")

    @ttl.setter
    def ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "ttl", value)

    @property
    @pulumi.getter(name="useClientSubnet")
    def use_client_subnet(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to use EDNS client subnet data when
        available(in filter chain).
        * ` meta` - (Optional) meta is supported at the `record` level. Meta
        is documented below.
        """
        return pulumi.get(self, "use_client_subnet")

    @use_client_subnet.setter
    def use_client_subnet(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "use_client_subnet", value)


@pulumi.input_type
class _RecordState:
    def __init__(__self__, *,
                 answers: Optional[pulumi.Input[Sequence[pulumi.Input['RecordAnswerArgs']]]] = None,
                 blocked_tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 domain: Optional[pulumi.Input[str]] = None,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input['RecordFilterArgs']]]] = None,
                 link: Optional[pulumi.Input[str]] = None,
                 meta: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 override_ttl: Optional[pulumi.Input[bool]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input['RecordRegionArgs']]]] = None,
                 short_answers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 ttl: Optional[pulumi.Input[int]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 use_client_subnet: Optional[pulumi.Input[bool]] = None,
                 zone: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Record resources.
        :param pulumi.Input[Sequence[pulumi.Input['RecordAnswerArgs']]] answers: One or more NS1 answers for the records' specified type.
               Answers are documented below.
        :param pulumi.Input[str] domain: The records' domain. Cannot have leading or trailing
               dots - see the example above and `FQDN formatting` below.
        :param pulumi.Input[Sequence[pulumi.Input['RecordFilterArgs']]] filters: One or more NS1 filters for the record(order matters).
               Filters are documented below.
        :param pulumi.Input[str] link: The target record to link to. This means this record is a
               'linked' record, and it inherits all properties from its target.
        :param pulumi.Input[Sequence[pulumi.Input['RecordRegionArgs']]] regions: One or more "regions" for the record. These are really
               just groupings based on metadata, and are called "Answer Groups" in the NS1 UI,
               but remain `regions` here for legacy reasons. Regions are
               documented below. Please note the ordering requirement!
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: map of tags in the form of `"key" = "value"` where both key and value are strings
        :param pulumi.Input[int] ttl: The records' time to live (in seconds).
        :param pulumi.Input[str] type: The records' RR type.
        :param pulumi.Input[bool] use_client_subnet: Whether to use EDNS client subnet data when
               available(in filter chain).
               * ` meta` - (Optional) meta is supported at the `record` level. Meta
               is documented below.
        :param pulumi.Input[str] zone: The zone the record belongs to. Cannot have leading or
               trailing dots (".") - see the example above and `FQDN formatting` below.
        """
        if answers is not None:
            pulumi.set(__self__, "answers", answers)
        if blocked_tags is not None:
            pulumi.set(__self__, "blocked_tags", blocked_tags)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if filters is not None:
            pulumi.set(__self__, "filters", filters)
        if link is not None:
            pulumi.set(__self__, "link", link)
        if meta is not None:
            pulumi.set(__self__, "meta", meta)
        if override_ttl is not None:
            pulumi.set(__self__, "override_ttl", override_ttl)
        if regions is not None:
            pulumi.set(__self__, "regions", regions)
        if short_answers is not None:
            warnings.warn("""short_answers will be deprecated in a future release. It is suggested to migrate to a regular \"answers\" block.""", DeprecationWarning)
            pulumi.log.warn("""short_answers is deprecated: short_answers will be deprecated in a future release. It is suggested to migrate to a regular \"answers\" block.""")
        if short_answers is not None:
            pulumi.set(__self__, "short_answers", short_answers)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if ttl is not None:
            pulumi.set(__self__, "ttl", ttl)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if use_client_subnet is not None:
            pulumi.set(__self__, "use_client_subnet", use_client_subnet)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter
    def answers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RecordAnswerArgs']]]]:
        """
        One or more NS1 answers for the records' specified type.
        Answers are documented below.
        """
        return pulumi.get(self, "answers")

    @answers.setter
    def answers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RecordAnswerArgs']]]]):
        pulumi.set(self, "answers", value)

    @property
    @pulumi.getter(name="blockedTags")
    def blocked_tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "blocked_tags")

    @blocked_tags.setter
    def blocked_tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "blocked_tags", value)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[str]]:
        """
        The records' domain. Cannot have leading or trailing
        dots - see the example above and `FQDN formatting` below.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter
    def filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RecordFilterArgs']]]]:
        """
        One or more NS1 filters for the record(order matters).
        Filters are documented below.
        """
        return pulumi.get(self, "filters")

    @filters.setter
    def filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RecordFilterArgs']]]]):
        pulumi.set(self, "filters", value)

    @property
    @pulumi.getter
    def link(self) -> Optional[pulumi.Input[str]]:
        """
        The target record to link to. This means this record is a
        'linked' record, and it inherits all properties from its target.
        """
        return pulumi.get(self, "link")

    @link.setter
    def link(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "link", value)

    @property
    @pulumi.getter
    def meta(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        return pulumi.get(self, "meta")

    @meta.setter
    def meta(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "meta", value)

    @property
    @pulumi.getter(name="overrideTtl")
    def override_ttl(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "override_ttl")

    @override_ttl.setter
    def override_ttl(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "override_ttl", value)

    @property
    @pulumi.getter
    def regions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RecordRegionArgs']]]]:
        """
        One or more "regions" for the record. These are really
        just groupings based on metadata, and are called "Answer Groups" in the NS1 UI,
        but remain `regions` here for legacy reasons. Regions are
        documented below. Please note the ordering requirement!
        """
        return pulumi.get(self, "regions")

    @regions.setter
    def regions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RecordRegionArgs']]]]):
        pulumi.set(self, "regions", value)

    @property
    @pulumi.getter(name="shortAnswers")
    @_utilities.deprecated("""short_answers will be deprecated in a future release. It is suggested to migrate to a regular \"answers\" block.""")
    def short_answers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "short_answers")

    @short_answers.setter
    def short_answers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "short_answers", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        map of tags in the form of `"key" = "value"` where both key and value are strings
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def ttl(self) -> Optional[pulumi.Input[int]]:
        """
        The records' time to live (in seconds).
        """
        return pulumi.get(self, "ttl")

    @ttl.setter
    def ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "ttl", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        The records' RR type.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="useClientSubnet")
    def use_client_subnet(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to use EDNS client subnet data when
        available(in filter chain).
        * ` meta` - (Optional) meta is supported at the `record` level. Meta
        is documented below.
        """
        return pulumi.get(self, "use_client_subnet")

    @use_client_subnet.setter
    def use_client_subnet(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "use_client_subnet", value)

    @property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[str]]:
        """
        The zone the record belongs to. Cannot have leading or
        trailing dots (".") - see the example above and `FQDN formatting` below.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "zone", value)


class Record(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 answers: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RecordAnswerArgs']]]]] = None,
                 blocked_tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 domain: Optional[pulumi.Input[str]] = None,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RecordFilterArgs']]]]] = None,
                 link: Optional[pulumi.Input[str]] = None,
                 meta: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 override_ttl: Optional[pulumi.Input[bool]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RecordRegionArgs']]]]] = None,
                 short_answers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 ttl: Optional[pulumi.Input[int]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 use_client_subnet: Optional[pulumi.Input[bool]] = None,
                 zone: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a NS1 Record resource. This can be used to create, modify, and delete records.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumi_external as external
        import pulumi_ns1 as ns1
        import pulumi_std as std

        example = ns1.Zone("example", zone="terraform.example.io")
        ns1 = ns1.DataSource("ns1",
            name="ns1_source",
            sourcetype="nsone_v1")
        foo = ns1.DataFeed("foo",
            name="foo_feed",
            source_id=ns1.id,
            config={
                "label": "foo",
            })
        bar = ns1.DataFeed("bar",
            name="bar_feed",
            source_id=ns1.id,
            config={
                "label": "bar",
            })
        www = ns1.Record("www",
            zone=tld["zone"],
            domain=f"www.{tld['zone']}",
            type="CNAME",
            ttl=60,
            meta={
                "up": True,
            },
            regions=[
                ns1.RecordRegionArgs(
                    name="east",
                    meta={
                        "georegion": "US-EAST",
                    },
                ),
                ns1.RecordRegionArgs(
                    name="usa",
                    meta={
                        "country": "US",
                    },
                ),
            ],
            answers=[
                ns1.RecordAnswerArgs(
                    answer=f"sub1.{tld['zone']}",
                    region="east",
                    meta={
                        "up": foo.id.apply(lambda id: f"{{\\"feed\\":\\"{id}\\"}}"),
                    },
                ),
                ns1.RecordAnswerArgs(
                    answer=f"sub2.{tld['zone']}",
                    meta={
                        "up": bar.id.apply(lambda id: f"{{\\"feed\\":\\"{id}\\"}}"),
                        "connections": 3,
                    },
                ),
                ns1.RecordAnswerArgs(
                    answer=f"sub3.{tld['zone']}",
                    meta={
                        "pulsar": json.dumps([{
                            "job_id": "abcdef",
                            "bias": "*0.55",
                            "a5m_cutoff": 0.9,
                        }]),
                        "subdivisions": json.dumps({
                            "BR": [
                                "SP",
                                "SC",
                            ],
                            "DZ": [
                                "01",
                                "02",
                                "03",
                            ],
                        }),
                    },
                ),
            ],
            filters=[ns1.RecordFilterArgs(
                filter="select_first_n",
                config={
                    "N": 1,
                },
            )])
        # Some other non-NS1 provider that returns a zone with a trailing dot and a domain with a leading dot.
        baz = external.index.Source("baz",
            zone=terraform.example.io.,
            domain=.www.terraform.example.io)
        # Basic record showing how to clean a zone or domain field that comes from
        # another non-NS1 resource. DNS names often end in '.' characters to signify
        # the root of the DNS tree, but the NS1 provider does not support this.
        #
        # In other cases, a domain or zone may be passed in with a preceding dot ('.')
        # character which would likewise lead the system to fail.
        external = ns1.Record("external",
            zone=std.replace(text=zone,
                search="/(^\\\\.)|(\\\\.$)/",
                replace="").result,
            domain=std.replace(text=domain,
                search="/(^\\\\.)|(\\\\.$)/",
                replace="").result,
            type="CNAME")
        ```

        ## NS1 Documentation

        [Record Api Doc](https://ns1.com/api#records)

        ## Import

        ```sh
        $ pulumi import ns1:index/record:Record <name> <zone>/<domain>/<type>`
        ```

        So for the example above:

        ```sh
        $ pulumi import ns1:index/record:Record www terraform.example.io/www.terraform.example.io/CNAME`
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RecordAnswerArgs']]]] answers: One or more NS1 answers for the records' specified type.
               Answers are documented below.
        :param pulumi.Input[str] domain: The records' domain. Cannot have leading or trailing
               dots - see the example above and `FQDN formatting` below.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RecordFilterArgs']]]] filters: One or more NS1 filters for the record(order matters).
               Filters are documented below.
        :param pulumi.Input[str] link: The target record to link to. This means this record is a
               'linked' record, and it inherits all properties from its target.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RecordRegionArgs']]]] regions: One or more "regions" for the record. These are really
               just groupings based on metadata, and are called "Answer Groups" in the NS1 UI,
               but remain `regions` here for legacy reasons. Regions are
               documented below. Please note the ordering requirement!
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: map of tags in the form of `"key" = "value"` where both key and value are strings
        :param pulumi.Input[int] ttl: The records' time to live (in seconds).
        :param pulumi.Input[str] type: The records' RR type.
        :param pulumi.Input[bool] use_client_subnet: Whether to use EDNS client subnet data when
               available(in filter chain).
               * ` meta` - (Optional) meta is supported at the `record` level. Meta
               is documented below.
        :param pulumi.Input[str] zone: The zone the record belongs to. Cannot have leading or
               trailing dots (".") - see the example above and `FQDN formatting` below.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RecordArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a NS1 Record resource. This can be used to create, modify, and delete records.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumi_external as external
        import pulumi_ns1 as ns1
        import pulumi_std as std

        example = ns1.Zone("example", zone="terraform.example.io")
        ns1 = ns1.DataSource("ns1",
            name="ns1_source",
            sourcetype="nsone_v1")
        foo = ns1.DataFeed("foo",
            name="foo_feed",
            source_id=ns1.id,
            config={
                "label": "foo",
            })
        bar = ns1.DataFeed("bar",
            name="bar_feed",
            source_id=ns1.id,
            config={
                "label": "bar",
            })
        www = ns1.Record("www",
            zone=tld["zone"],
            domain=f"www.{tld['zone']}",
            type="CNAME",
            ttl=60,
            meta={
                "up": True,
            },
            regions=[
                ns1.RecordRegionArgs(
                    name="east",
                    meta={
                        "georegion": "US-EAST",
                    },
                ),
                ns1.RecordRegionArgs(
                    name="usa",
                    meta={
                        "country": "US",
                    },
                ),
            ],
            answers=[
                ns1.RecordAnswerArgs(
                    answer=f"sub1.{tld['zone']}",
                    region="east",
                    meta={
                        "up": foo.id.apply(lambda id: f"{{\\"feed\\":\\"{id}\\"}}"),
                    },
                ),
                ns1.RecordAnswerArgs(
                    answer=f"sub2.{tld['zone']}",
                    meta={
                        "up": bar.id.apply(lambda id: f"{{\\"feed\\":\\"{id}\\"}}"),
                        "connections": 3,
                    },
                ),
                ns1.RecordAnswerArgs(
                    answer=f"sub3.{tld['zone']}",
                    meta={
                        "pulsar": json.dumps([{
                            "job_id": "abcdef",
                            "bias": "*0.55",
                            "a5m_cutoff": 0.9,
                        }]),
                        "subdivisions": json.dumps({
                            "BR": [
                                "SP",
                                "SC",
                            ],
                            "DZ": [
                                "01",
                                "02",
                                "03",
                            ],
                        }),
                    },
                ),
            ],
            filters=[ns1.RecordFilterArgs(
                filter="select_first_n",
                config={
                    "N": 1,
                },
            )])
        # Some other non-NS1 provider that returns a zone with a trailing dot and a domain with a leading dot.
        baz = external.index.Source("baz",
            zone=terraform.example.io.,
            domain=.www.terraform.example.io)
        # Basic record showing how to clean a zone or domain field that comes from
        # another non-NS1 resource. DNS names often end in '.' characters to signify
        # the root of the DNS tree, but the NS1 provider does not support this.
        #
        # In other cases, a domain or zone may be passed in with a preceding dot ('.')
        # character which would likewise lead the system to fail.
        external = ns1.Record("external",
            zone=std.replace(text=zone,
                search="/(^\\\\.)|(\\\\.$)/",
                replace="").result,
            domain=std.replace(text=domain,
                search="/(^\\\\.)|(\\\\.$)/",
                replace="").result,
            type="CNAME")
        ```

        ## NS1 Documentation

        [Record Api Doc](https://ns1.com/api#records)

        ## Import

        ```sh
        $ pulumi import ns1:index/record:Record <name> <zone>/<domain>/<type>`
        ```

        So for the example above:

        ```sh
        $ pulumi import ns1:index/record:Record www terraform.example.io/www.terraform.example.io/CNAME`
        ```

        :param str resource_name: The name of the resource.
        :param RecordArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RecordArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 answers: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RecordAnswerArgs']]]]] = None,
                 blocked_tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 domain: Optional[pulumi.Input[str]] = None,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RecordFilterArgs']]]]] = None,
                 link: Optional[pulumi.Input[str]] = None,
                 meta: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 override_ttl: Optional[pulumi.Input[bool]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RecordRegionArgs']]]]] = None,
                 short_answers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 ttl: Optional[pulumi.Input[int]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 use_client_subnet: Optional[pulumi.Input[bool]] = None,
                 zone: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RecordArgs.__new__(RecordArgs)

            __props__.__dict__["answers"] = answers
            __props__.__dict__["blocked_tags"] = blocked_tags
            if domain is None and not opts.urn:
                raise TypeError("Missing required property 'domain'")
            __props__.__dict__["domain"] = domain
            __props__.__dict__["filters"] = filters
            __props__.__dict__["link"] = link
            __props__.__dict__["meta"] = meta
            __props__.__dict__["override_ttl"] = override_ttl
            __props__.__dict__["regions"] = regions
            __props__.__dict__["short_answers"] = short_answers
            __props__.__dict__["tags"] = tags
            __props__.__dict__["ttl"] = ttl
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["use_client_subnet"] = use_client_subnet
            if zone is None and not opts.urn:
                raise TypeError("Missing required property 'zone'")
            __props__.__dict__["zone"] = zone
        super(Record, __self__).__init__(
            'ns1:index/record:Record',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            answers: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RecordAnswerArgs']]]]] = None,
            blocked_tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            domain: Optional[pulumi.Input[str]] = None,
            filters: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RecordFilterArgs']]]]] = None,
            link: Optional[pulumi.Input[str]] = None,
            meta: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            override_ttl: Optional[pulumi.Input[bool]] = None,
            regions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RecordRegionArgs']]]]] = None,
            short_answers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            ttl: Optional[pulumi.Input[int]] = None,
            type: Optional[pulumi.Input[str]] = None,
            use_client_subnet: Optional[pulumi.Input[bool]] = None,
            zone: Optional[pulumi.Input[str]] = None) -> 'Record':
        """
        Get an existing Record resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RecordAnswerArgs']]]] answers: One or more NS1 answers for the records' specified type.
               Answers are documented below.
        :param pulumi.Input[str] domain: The records' domain. Cannot have leading or trailing
               dots - see the example above and `FQDN formatting` below.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RecordFilterArgs']]]] filters: One or more NS1 filters for the record(order matters).
               Filters are documented below.
        :param pulumi.Input[str] link: The target record to link to. This means this record is a
               'linked' record, and it inherits all properties from its target.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RecordRegionArgs']]]] regions: One or more "regions" for the record. These are really
               just groupings based on metadata, and are called "Answer Groups" in the NS1 UI,
               but remain `regions` here for legacy reasons. Regions are
               documented below. Please note the ordering requirement!
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: map of tags in the form of `"key" = "value"` where both key and value are strings
        :param pulumi.Input[int] ttl: The records' time to live (in seconds).
        :param pulumi.Input[str] type: The records' RR type.
        :param pulumi.Input[bool] use_client_subnet: Whether to use EDNS client subnet data when
               available(in filter chain).
               * ` meta` - (Optional) meta is supported at the `record` level. Meta
               is documented below.
        :param pulumi.Input[str] zone: The zone the record belongs to. Cannot have leading or
               trailing dots (".") - see the example above and `FQDN formatting` below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RecordState.__new__(_RecordState)

        __props__.__dict__["answers"] = answers
        __props__.__dict__["blocked_tags"] = blocked_tags
        __props__.__dict__["domain"] = domain
        __props__.__dict__["filters"] = filters
        __props__.__dict__["link"] = link
        __props__.__dict__["meta"] = meta
        __props__.__dict__["override_ttl"] = override_ttl
        __props__.__dict__["regions"] = regions
        __props__.__dict__["short_answers"] = short_answers
        __props__.__dict__["tags"] = tags
        __props__.__dict__["ttl"] = ttl
        __props__.__dict__["type"] = type
        __props__.__dict__["use_client_subnet"] = use_client_subnet
        __props__.__dict__["zone"] = zone
        return Record(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def answers(self) -> pulumi.Output[Optional[Sequence['outputs.RecordAnswer']]]:
        """
        One or more NS1 answers for the records' specified type.
        Answers are documented below.
        """
        return pulumi.get(self, "answers")

    @property
    @pulumi.getter(name="blockedTags")
    def blocked_tags(self) -> pulumi.Output[Optional[Sequence[str]]]:
        return pulumi.get(self, "blocked_tags")

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Output[str]:
        """
        The records' domain. Cannot have leading or trailing
        dots - see the example above and `FQDN formatting` below.
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter
    def filters(self) -> pulumi.Output[Optional[Sequence['outputs.RecordFilter']]]:
        """
        One or more NS1 filters for the record(order matters).
        Filters are documented below.
        """
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def link(self) -> pulumi.Output[Optional[str]]:
        """
        The target record to link to. This means this record is a
        'linked' record, and it inherits all properties from its target.
        """
        return pulumi.get(self, "link")

    @property
    @pulumi.getter
    def meta(self) -> pulumi.Output[Optional[Mapping[str, Any]]]:
        return pulumi.get(self, "meta")

    @property
    @pulumi.getter(name="overrideTtl")
    def override_ttl(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "override_ttl")

    @property
    @pulumi.getter
    def regions(self) -> pulumi.Output[Optional[Sequence['outputs.RecordRegion']]]:
        """
        One or more "regions" for the record. These are really
        just groupings based on metadata, and are called "Answer Groups" in the NS1 UI,
        but remain `regions` here for legacy reasons. Regions are
        documented below. Please note the ordering requirement!
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter(name="shortAnswers")
    @_utilities.deprecated("""short_answers will be deprecated in a future release. It is suggested to migrate to a regular \"answers\" block.""")
    def short_answers(self) -> pulumi.Output[Optional[Sequence[str]]]:
        return pulumi.get(self, "short_answers")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        map of tags in the form of `"key" = "value"` where both key and value are strings
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def ttl(self) -> pulumi.Output[int]:
        """
        The records' time to live (in seconds).
        """
        return pulumi.get(self, "ttl")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        The records' RR type.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="useClientSubnet")
    def use_client_subnet(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether to use EDNS client subnet data when
        available(in filter chain).
        * ` meta` - (Optional) meta is supported at the `record` level. Meta
        is documented below.
        """
        return pulumi.get(self, "use_client_subnet")

    @property
    @pulumi.getter
    def zone(self) -> pulumi.Output[str]:
        """
        The zone the record belongs to. Cannot have leading or
        trailing dots (".") - see the example above and `FQDN formatting` below.
        """
        return pulumi.get(self, "zone")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .account_whitelist import *
from .api_key import *
from .application import *
from .data_feed import *
from .data_source import *
from .dataset import *
from .dnsview import *
from .get_dns_sec import *
from .get_monitoring_regions import *
from .get_networks import *
from .get_record import *
from .get_zone import *
from .monitoring_job import *
from .notify_list import *
from .provider import *
from .pulsar_job import *
from .record import *
from .redirect import *
from .redirect_certificate import *
from .subnet import *
from .team import *
from .tsigkey import *
from .user import *
from .zone import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_ns1.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_ns1.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "ns1",
  "mod": "index/aPIKey",
  "fqn": "pulumi_ns1",
  "classes": {
   "ns1:index/aPIKey:APIKey": "APIKey"
  }
 },
 {
  "pkg": "ns1",
  "mod": "index/accountWhitelist",
  "fqn": "pulumi_ns1",
  "classes": {
   "ns1:index/accountWhitelist:AccountWhitelist": "AccountWhitelist"
  }
 },
 {
  "pkg": "ns1",
  "mod": "index/application",
  "fqn": "pulumi_ns1",
  "classes": {
   "ns1:index/application:Application": "Application"
  }
 },
 {
  "pkg": "ns1",
  "mod": "index/dataFeed",
  "fqn": "pulumi_ns1",
  "classes": {
   "ns1:index/dataFeed:DataFeed": "DataFeed"
  }
 },
 {
  "pkg": "ns1",
  "mod": "index/dataSource",
  "fqn": "pulumi_ns1",
  "classes": {
   "ns1:index/dataSource:DataSource": "DataSource"
  }
 },
 {
  "pkg": "ns1",
  "mod": "index/dataset",
  "fqn": "pulumi_ns1",
  "classes": {
   "ns1:index/dataset:Dataset": "Dataset"
  }
 },
 {
  "pkg": "ns1",
  "mod": "index/dnsview",
  "fqn": "pulumi_ns1",
  "classes": {
   "ns1:index/dnsview:Dnsview": "Dnsview"
  }
 },
 {
  "pkg": "ns1",
  "mod": "index/monitoringJob",
  "fqn": "pulumi_ns1",
  "classes": {
   "ns1:index/monitoringJob:MonitoringJob": "MonitoringJob"
  }
 },
 {
  "pkg": "ns1",
  "mod": "index/notifyList",
  "fqn": "pulumi_ns1",
  "classes": {
   "ns1:index/notifyList:NotifyList": "NotifyList"
  }
 },
 {
  "pkg": "ns1",
  "mod": "index/pulsarJob",
  "fqn": "pulumi_ns1",
  "classes": {
   "ns1:index/pulsarJob:PulsarJob": "PulsarJob"
  }
 },
 {
  "pkg": "ns1",
  "mod": "index/record",
  "fqn": "pulumi_ns1",
  "classes": {
   "ns1:index/record:Record": "Record"
  }
 },
 {
  "pkg": "ns1",
  "mod": "index/redirect",
  "fqn": "pulumi_ns1",
  "classes": {
   "ns1:index/redirect:Redirect": "Redirect"
  }
 },
 {
  "pkg": "ns1",
  "mod": "index/redirectCertificate",
  "fqn": "pulumi_ns1",
  "classes": {
   "ns1:index/redirectCertificate:RedirectCertificate": "RedirectCertificate"
  }
 },
 {
  "pkg": "ns1",
  "mod": "index/subnet",
  "fqn": "pulumi_ns1",
  "classes": {
   "ns1:index/subnet:Subnet": "Subnet"
  }
 },
 {
  "pkg": "ns1",
  "mod": "index/team",
  "fqn": "pulumi_ns1",
  "classes": {
   "ns1:index/team:Team": "Team"
  }
 },
 {
  "pkg": "ns1",
  "mod": "index/tsigkey",
  "fqn": "pulumi_ns1",
  "classes": {
   "ns1:index/tsigkey:Tsigkey": "Tsigkey"
  }
 },
 {
  "pkg": "ns1",
  "mod": "index/user",
  "fqn": "pulumi_ns1",
  "classes": {
   "ns1:index/user:User": "User"
  }
 },
 {
  "pkg": "ns1",
  "mod": "index/zone",
  "fqn": "pulumi_ns1",
  "classes": {
   "ns1:index/zone:Zone": "Zone"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "ns1",
  "token": "pulumi:providers:ns1",
  "fqn": "pulumi_ns1",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['DnsviewArgs', 'Dnsview']

@pulumi.input_type
class DnsviewArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[str]] = None,
                 networks: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 preference: Optional[pulumi.Input[int]] = None,
                 read_acls: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 update_acls: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 zones: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a Dnsview resource.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if networks is not None:
            pulumi.set(__self__, "networks", networks)
        if preference is not None:
            pulumi.set(__self__, "preference", preference)
        if read_acls is not None:
            pulumi.set(__self__, "read_acls", read_acls)
        if update_acls is not None:
            pulumi.set(__self__, "update_acls", update_acls)
        if zones is not None:
            pulumi.set(__self__, "zones", zones)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        return pulumi.get(self, "networks")

    @networks.setter
    def networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "networks", value)

    @property
    @pulumi.getter
    def preference(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "preference")

    @preference.setter
    def preference(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "preference", value)

    @property
    @pulumi.getter(name="readAcls")
    def read_acls(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "read_acls")

    @read_acls.setter
    def read_acls(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "read_acls", value)

    @property
    @pulumi.getter(name="updateAcls")
    def update_acls(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "update_acls")

    @update_acls.setter
    def update_acls(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "update_acls", value)

    @property
    @pulumi.getter
    def zones(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "zones")

    @zones.setter
    def zones(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "zones", value)


@pulumi.input_type
class _DnsviewState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 networks: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 preference: Optional[pulumi.Input[int]] = None,
                 read_acls: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 update_acls: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 updated_at: Optional[pulumi.Input[int]] = None,
                 zones: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering Dnsview resources.
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if networks is not None:
            pulumi.set(__self__, "networks", networks)
        if preference is not None:
            pulumi.set(__self__, "preference", preference)
        if read_acls is not None:
            pulumi.set(__self__, "read_acls", read_acls)
        if update_acls is not None:
            pulumi.set(__self__, "update_acls", update_acls)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if zones is not None:
            pulumi.set(__self__, "zones", zones)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        return pulumi.get(self, "networks")

    @networks.setter
    def networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "networks", value)

    @property
    @pulumi.getter
    def preference(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "preference")

    @preference.setter
    def preference(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "preference", value)

    @property
    @pulumi.getter(name="readAcls")
    def read_acls(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "read_acls")

    @read_acls.setter
    def read_acls(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "read_acls", value)

    @property
    @pulumi.getter(name="updateAcls")
    def update_acls(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "update_acls")

    @update_acls.setter
    def update_acls(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "update_acls", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter
    def zones(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "zones")

    @zones.setter
    def zones(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "zones", value)


class Dnsview(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 networks: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 preference: Optional[pulumi.Input[int]] = None,
                 read_acls: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 update_acls: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 zones: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Create a Dnsview resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[DnsviewArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a Dnsview resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param DnsviewArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DnsviewArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 networks: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 preference: Optional[pulumi.Input[int]] = None,
                 read_acls: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 update_acls: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 zones: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DnsviewArgs.__new__(DnsviewArgs)

            __props__.__dict__["name"] = name
            __props__.__dict__["networks"] = networks
            __props__.__dict__["preference"] = preference
            __props__.__dict__["read_acls"] = read_acls
            __props__.__dict__["update_acls"] = update_acls
            __props__.__dict__["zones"] = zones
            __props__.__dict__["created_at"] = None
            __props__.__dict__["updated_at"] = None
        super(Dnsview, __self__).__init__(
            'ns1:index/dnsview:Dnsview',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[int]] = None,
            name: Optional[pulumi.Input[str]] = None,
            networks: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
            preference: Optional[pulumi.Input[int]] = None,
            read_acls: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            update_acls: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            updated_at: Optional[pulumi.Input[int]] = None,
            zones: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'Dnsview':
        """
        Get an existing Dnsview resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DnsviewState.__new__(_DnsviewState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["name"] = name
        __props__.__dict__["networks"] = networks
        __props__.__dict__["preference"] = preference
        __props__.__dict__["read_acls"] = read_acls
        __props__.__dict__["update_acls"] = update_acls
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["zones"] = zones
        return Dnsview(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[int]:
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def networks(self) -> pulumi.Output[Optional[Sequence[int]]]:
        return pulumi.get(self, "networks")

    @property
    @pulumi.getter
    def preference(self) -> pulumi.Output[int]:
        return pulumi.get(self, "preference")

    @property
    @pulumi.getter(name="readAcls")
    def read_acls(self) -> pulumi.Output[Optional[Sequence[str]]]:
        return pulumi.get(self, "read_acls")

    @property
    @pulumi.getter(name="updateAcls")
    def update_acls(self) -> pulumi.Output[Optional[Sequence[str]]]:
        return pulumi.get(self, "update_acls")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[int]:
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter
    def zones(self) -> pulumi.Output[Optional[Sequence[str]]]:
        return pulumi.get(self, "zones")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['MonitoringJobArgs', 'MonitoringJob']

@pulumi.input_type
class MonitoringJobArgs:
    def __init__(__self__, *,
                 config: pulumi.Input[Mapping[str, Any]],
                 frequency: pulumi.Input[int],
                 job_type: pulumi.Input[str],
                 regions: pulumi.Input[Sequence[pulumi.Input[str]]],
                 active: Optional[pulumi.Input[bool]] = None,
                 mute: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 notes: Optional[pulumi.Input[str]] = None,
                 notify_delay: Optional[pulumi.Input[int]] = None,
                 notify_failback: Optional[pulumi.Input[bool]] = None,
                 notify_list: Optional[pulumi.Input[str]] = None,
                 notify_regional: Optional[pulumi.Input[bool]] = None,
                 notify_repeat: Optional[pulumi.Input[int]] = None,
                 policy: Optional[pulumi.Input[str]] = None,
                 rapid_recheck: Optional[pulumi.Input[bool]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input['MonitoringJobRuleArgs']]]] = None):
        """
        The set of arguments for constructing a MonitoringJob resource.
        :param pulumi.Input[Mapping[str, Any]] config: A configuration dictionary with keys and values depending on the job_type. Configuration details for each job_type are found by submitting a GET request to https://api.nsone.net/v1/monitoring/jobtypes.
        :param pulumi.Input[int] frequency: The frequency, in seconds, at which to run the monitoring job in each region.
        :param pulumi.Input[str] job_type: The type of monitoring job to be run. Refer to the NS1 API documentation (https://ns1.com/api#monitoring-jobs) for supported values which include ping, tcp, dns, http.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regions: The list of region codes in which to run the monitoring
               job. See NS1 API docs for supported values.
        :param pulumi.Input[bool] active: Indicates if the job is active or temporarily disabled.
        :param pulumi.Input[bool] mute: turn off the notifications for the monitoring job.
        :param pulumi.Input[str] name: The free-form display name for the monitoring job.
        :param pulumi.Input[str] notes: Freeform notes to be included in any notifications about this job.
        :param pulumi.Input[int] notify_delay: The time in seconds after a failure to wait before sending a notification.
        :param pulumi.Input[bool] notify_failback: If true, a notification is sent when a job returns to an "up" state.
        :param pulumi.Input[bool] notify_regional: If true, notifications are sent for any regional failure (and failback if desired), in addition to global state notifications.
        :param pulumi.Input[int] notify_repeat: The time in seconds between repeat notifications of a failed job.
        :param pulumi.Input[str] policy: The policy for determining the monitor's global status
               based on the status of the job in all regions. See NS1 API docs for supported values.
        :param pulumi.Input[bool] rapid_recheck: If true, on any apparent state change, the job is quickly re-run after one second to confirm the state change before notification.
        :param pulumi.Input[Sequence[pulumi.Input['MonitoringJobRuleArgs']]] rules: A list of rules for determining failure conditions. Each rule acts on one of the outputs from the monitoring job. You must specify key (the output key); comparison (a comparison to perform on the the output); and value (the value to compare to). For example, {"key":"rtt", "comparison":"<", "value":100} is a rule requiring the rtt from a job to be under 100ms, or the job will be marked failed. Available output keys, comparators, and value types are are found by submitting a GET request to https://api.nsone.net/v1/monitoring/jobtypes.
        """
        pulumi.set(__self__, "config", config)
        pulumi.set(__self__, "frequency", frequency)
        pulumi.set(__self__, "job_type", job_type)
        pulumi.set(__self__, "regions", regions)
        if active is not None:
            pulumi.set(__self__, "active", active)
        if mute is not None:
            pulumi.set(__self__, "mute", mute)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notes is not None:
            pulumi.set(__self__, "notes", notes)
        if notify_delay is not None:
            pulumi.set(__self__, "notify_delay", notify_delay)
        if notify_failback is not None:
            pulumi.set(__self__, "notify_failback", notify_failback)
        if notify_list is not None:
            pulumi.set(__self__, "notify_list", notify_list)
        if notify_regional is not None:
            pulumi.set(__self__, "notify_regional", notify_regional)
        if notify_repeat is not None:
            pulumi.set(__self__, "notify_repeat", notify_repeat)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if rapid_recheck is not None:
            pulumi.set(__self__, "rapid_recheck", rapid_recheck)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter
    def config(self) -> pulumi.Input[Mapping[str, Any]]:
        """
        A configuration dictionary with keys and values depending on the job_type. Configuration details for each job_type are found by submitting a GET request to https://api.nsone.net/v1/monitoring/jobtypes.
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: pulumi.Input[Mapping[str, Any]]):
        pulumi.set(self, "config", value)

    @property
    @pulumi.getter
    def frequency(self) -> pulumi.Input[int]:
        """
        The frequency, in seconds, at which to run the monitoring job in each region.
        """
        return pulumi.get(self, "frequency")

    @frequency.setter
    def frequency(self, value: pulumi.Input[int]):
        pulumi.set(self, "frequency", value)

    @property
    @pulumi.getter(name="jobType")
    def job_type(self) -> pulumi.Input[str]:
        """
        The type of monitoring job to be run. Refer to the NS1 API documentation (https://ns1.com/api#monitoring-jobs) for supported values which include ping, tcp, dns, http.
        """
        return pulumi.get(self, "job_type")

    @job_type.setter
    def job_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "job_type", value)

    @property
    @pulumi.getter
    def regions(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The list of region codes in which to run the monitoring
        job. See NS1 API docs for supported values.
        """
        return pulumi.get(self, "regions")

    @regions.setter
    def regions(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "regions", value)

    @property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates if the job is active or temporarily disabled.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "active", value)

    @property
    @pulumi.getter
    def mute(self) -> Optional[pulumi.Input[bool]]:
        """
        turn off the notifications for the monitoring job.
        """
        return pulumi.get(self, "mute")

    @mute.setter
    def mute(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "mute", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The free-form display name for the monitoring job.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def notes(self) -> Optional[pulumi.Input[str]]:
        """
        Freeform notes to be included in any notifications about this job.
        """
        return pulumi.get(self, "notes")

    @notes.setter
    def notes(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "notes", value)

    @property
    @pulumi.getter(name="notifyDelay")
    def notify_delay(self) -> Optional[pulumi.Input[int]]:
        """
        The time in seconds after a failure to wait before sending a notification.
        """
        return pulumi.get(self, "notify_delay")

    @notify_delay.setter
    def notify_delay(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "notify_delay", value)

    @property
    @pulumi.getter(name="notifyFailback")
    def notify_failback(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, a notification is sent when a job returns to an "up" state.
        """
        return pulumi.get(self, "notify_failback")

    @notify_failback.setter
    def notify_failback(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "notify_failback", value)

    @property
    @pulumi.getter(name="notifyList")
    def notify_list(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "notify_list")

    @notify_list.setter
    def notify_list(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "notify_list", value)

    @property
    @pulumi.getter(name="notifyRegional")
    def notify_regional(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, notifications are sent for any regional failure (and failback if desired), in addition to global state notifications.
        """
        return pulumi.get(self, "notify_regional")

    @notify_regional.setter
    def notify_regional(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "notify_regional", value)

    @property
    @pulumi.getter(name="notifyRepeat")
    def notify_repeat(self) -> Optional[pulumi.Input[int]]:
        """
        The time in seconds between repeat notifications of a failed job.
        """
        return pulumi.get(self, "notify_repeat")

    @notify_repeat.setter
    def notify_repeat(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "notify_repeat", value)

    @property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[str]]:
        """
        The policy for determining the monitor's global status
        based on the status of the job in all regions. See NS1 API docs for supported values.
        """
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy", value)

    @property
    @pulumi.getter(name="rapidRecheck")
    def rapid_recheck(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, on any apparent state change, the job is quickly re-run after one second to confirm the state change before notification.
        """
        return pulumi.get(self, "rapid_recheck")

    @rapid_recheck.setter
    def rapid_recheck(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "rapid_recheck", value)

    @property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MonitoringJobRuleArgs']]]]:
        """
        A list of rules for determining failure conditions. Each rule acts on one of the outputs from the monitoring job. You must specify key (the output key); comparison (a comparison to perform on the the output); and value (the value to compare to). For example, {"key":"rtt", "comparison":"<", "value":100} is a rule requiring the rtt from a job to be under 100ms, or the job will be marked failed. Available output keys, comparators, and value types are are found by submitting a GET request to https://api.nsone.net/v1/monitoring/jobtypes.
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MonitoringJobRuleArgs']]]]):
        pulumi.set(self, "rules", value)


@pulumi.input_type
class _MonitoringJobState:
    def __init__(__self__, *,
                 active: Optional[pulumi.Input[bool]] = None,
                 config: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 frequency: Optional[pulumi.Input[int]] = None,
                 job_type: Optional[pulumi.Input[str]] = None,
                 mute: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 notes: Optional[pulumi.Input[str]] = None,
                 notify_delay: Optional[pulumi.Input[int]] = None,
                 notify_failback: Optional[pulumi.Input[bool]] = None,
                 notify_list: Optional[pulumi.Input[str]] = None,
                 notify_regional: Optional[pulumi.Input[bool]] = None,
                 notify_repeat: Optional[pulumi.Input[int]] = None,
                 policy: Optional[pulumi.Input[str]] = None,
                 rapid_recheck: Optional[pulumi.Input[bool]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input['MonitoringJobRuleArgs']]]] = None):
        """
        Input properties used for looking up and filtering MonitoringJob resources.
        :param pulumi.Input[bool] active: Indicates if the job is active or temporarily disabled.
        :param pulumi.Input[Mapping[str, Any]] config: A configuration dictionary with keys and values depending on the job_type. Configuration details for each job_type are found by submitting a GET request to https://api.nsone.net/v1/monitoring/jobtypes.
        :param pulumi.Input[int] frequency: The frequency, in seconds, at which to run the monitoring job in each region.
        :param pulumi.Input[str] job_type: The type of monitoring job to be run. Refer to the NS1 API documentation (https://ns1.com/api#monitoring-jobs) for supported values which include ping, tcp, dns, http.
        :param pulumi.Input[bool] mute: turn off the notifications for the monitoring job.
        :param pulumi.Input[str] name: The free-form display name for the monitoring job.
        :param pulumi.Input[str] notes: Freeform notes to be included in any notifications about this job.
        :param pulumi.Input[int] notify_delay: The time in seconds after a failure to wait before sending a notification.
        :param pulumi.Input[bool] notify_failback: If true, a notification is sent when a job returns to an "up" state.
        :param pulumi.Input[bool] notify_regional: If true, notifications are sent for any regional failure (and failback if desired), in addition to global state notifications.
        :param pulumi.Input[int] notify_repeat: The time in seconds between repeat notifications of a failed job.
        :param pulumi.Input[str] policy: The policy for determining the monitor's global status
               based on the status of the job in all regions. See NS1 API docs for supported values.
        :param pulumi.Input[bool] rapid_recheck: If true, on any apparent state change, the job is quickly re-run after one second to confirm the state change before notification.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regions: The list of region codes in which to run the monitoring
               job. See NS1 API docs for supported values.
        :param pulumi.Input[Sequence[pulumi.Input['MonitoringJobRuleArgs']]] rules: A list of rules for determining failure conditions. Each rule acts on one of the outputs from the monitoring job. You must specify key (the output key); comparison (a comparison to perform on the the output); and value (the value to compare to). For example, {"key":"rtt", "comparison":"<", "value":100} is a rule requiring the rtt from a job to be under 100ms, or the job will be marked failed. Available output keys, comparators, and value types are are found by submitting a GET request to https://api.nsone.net/v1/monitoring/jobtypes.
        """
        if active is not None:
            pulumi.set(__self__, "active", active)
        if config is not None:
            pulumi.set(__self__, "config", config)
        if frequency is not None:
            pulumi.set(__self__, "frequency", frequency)
        if job_type is not None:
            pulumi.set(__self__, "job_type", job_type)
        if mute is not None:
            pulumi.set(__self__, "mute", mute)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notes is not None:
            pulumi.set(__self__, "notes", notes)
        if notify_delay is not None:
            pulumi.set(__self__, "notify_delay", notify_delay)
        if notify_failback is not None:
            pulumi.set(__self__, "notify_failback", notify_failback)
        if notify_list is not None:
            pulumi.set(__self__, "notify_list", notify_list)
        if notify_regional is not None:
            pulumi.set(__self__, "notify_regional", notify_regional)
        if notify_repeat is not None:
            pulumi.set(__self__, "notify_repeat", notify_repeat)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if rapid_recheck is not None:
            pulumi.set(__self__, "rapid_recheck", rapid_recheck)
        if regions is not None:
            pulumi.set(__self__, "regions", regions)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates if the job is active or temporarily disabled.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "active", value)

    @property
    @pulumi.getter
    def config(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        A configuration dictionary with keys and values depending on the job_type. Configuration details for each job_type are found by submitting a GET request to https://api.nsone.net/v1/monitoring/jobtypes.
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "config", value)

    @property
    @pulumi.getter
    def frequency(self) -> Optional[pulumi.Input[int]]:
        """
        The frequency, in seconds, at which to run the monitoring job in each region.
        """
        return pulumi.get(self, "frequency")

    @frequency.setter
    def frequency(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "frequency", value)

    @property
    @pulumi.getter(name="jobType")
    def job_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of monitoring job to be run. Refer to the NS1 API documentation (https://ns1.com/api#monitoring-jobs) for supported values which include ping, tcp, dns, http.
        """
        return pulumi.get(self, "job_type")

    @job_type.setter
    def job_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "job_type", value)

    @property
    @pulumi.getter
    def mute(self) -> Optional[pulumi.Input[bool]]:
        """
        turn off the notifications for the monitoring job.
        """
        return pulumi.get(self, "mute")

    @mute.setter
    def mute(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "mute", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The free-form display name for the monitoring job.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def notes(self) -> Optional[pulumi.Input[str]]:
        """
        Freeform notes to be included in any notifications about this job.
        """
        return pulumi.get(self, "notes")

    @notes.setter
    def notes(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "notes", value)

    @property
    @pulumi.getter(name="notifyDelay")
    def notify_delay(self) -> Optional[pulumi.Input[int]]:
        """
        The time in seconds after a failure to wait before sending a notification.
        """
        return pulumi.get(self, "notify_delay")

    @notify_delay.setter
    def notify_delay(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "notify_delay", value)

    @property
    @pulumi.getter(name="notifyFailback")
    def notify_failback(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, a notification is sent when a job returns to an "up" state.
        """
        return pulumi.get(self, "notify_failback")

    @notify_failback.setter
    def notify_failback(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "notify_failback", value)

    @property
    @pulumi.getter(name="notifyList")
    def notify_list(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "notify_list")

    @notify_list.setter
    def notify_list(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "notify_list", value)

    @property
    @pulumi.getter(name="notifyRegional")
    def notify_regional(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, notifications are sent for any regional failure (and failback if desired), in addition to global state notifications.
        """
        return pulumi.get(self, "notify_regional")

    @notify_regional.setter
    def notify_regional(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "notify_regional", value)

    @property
    @pulumi.getter(name="notifyRepeat")
    def notify_repeat(self) -> Optional[pulumi.Input[int]]:
        """
        The time in seconds between repeat notifications of a failed job.
        """
        return pulumi.get(self, "notify_repeat")

    @notify_repeat.setter
    def notify_repeat(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "notify_repeat", value)

    @property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[str]]:
        """
        The policy for determining the monitor's global status
        based on the status of the job in all regions. See NS1 API docs for supported values.
        """
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy", value)

    @property
    @pulumi.getter(name="rapidRecheck")
    def rapid_recheck(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, on any apparent state change, the job is quickly re-run after one second to confirm the state change before notification.
        """
        return pulumi.get(self, "rapid_recheck")

    @rapid_recheck.setter
    def rapid_recheck(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "rapid_recheck", value)

    @property
    @pulumi.getter
    def regions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The list of region codes in which to run the monitoring
        job. See NS1 API docs for supported values.
        """
        return pulumi.get(self, "regions")

    @regions.setter
    def regions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "regions", value)

    @property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MonitoringJobRuleArgs']]]]:
        """
        A list of rules for determining failure conditions. Each rule acts on one of the outputs from the monitoring job. You must specify key (the output key); comparison (a comparison to perform on the the output); and value (the value to compare to). For example, {"key":"rtt", "comparison":"<", "value":100} is a rule requiring the rtt from a job to be under 100ms, or the job will be marked failed. Available output keys, comparators, and value types are are found by submitting a GET request to https://api.nsone.net/v1/monitoring/jobtypes.
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MonitoringJobRuleArgs']]]]):
        pulumi.set(self, "rules", value)


class MonitoringJob(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 active: Optional[pulumi.Input[bool]] = None,
                 config: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 frequency: Optional[pulumi.Input[int]] = None,
                 job_type: Optional[pulumi.Input[str]] = None,
                 mute: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 notes: Optional[pulumi.Input[str]] = None,
                 notify_delay: Optional[pulumi.Input[int]] = None,
                 notify_failback: Optional[pulumi.Input[bool]] = None,
                 notify_list: Optional[pulumi.Input[str]] = None,
                 notify_regional: Optional[pulumi.Input[bool]] = None,
                 notify_repeat: Optional[pulumi.Input[int]] = None,
                 policy: Optional[pulumi.Input[str]] = None,
                 rapid_recheck: Optional[pulumi.Input[bool]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MonitoringJobRuleArgs']]]]] = None,
                 __props__=None):
        """
        Provides a NS1 Monitoring Job resource. This can be used to create, modify, and delete monitoring jobs.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ns1 as ns1

        uswest_monitor = ns1.MonitoringJob("uswest_monitor",
            name="uswest",
            active=True,
            regions=[
                "lga",
                "sjc",
                "sin",
            ],
            job_type="tcp",
            frequency=60,
            rapid_recheck=True,
            policy="quorum",
            mute=True,
            config={
                "ssl": 1,
                "send": "HEAD / HTTP/1.0\\\\r\\\\n\\\\r\\\\n",
                "port": 443,
                "host": "example-elb-uswest.aws.amazon.com",
            },
            rules=[ns1.MonitoringJobRuleArgs(
                value="200 OK",
                comparison="contains",
                key="output",
            )])
        ```

        ## NS1 Documentation

        [MonitoringJob Api Doc](https://ns1.com/api#monitoring-jobs)

        ## Import

        ```sh
        $ pulumi import ns1:index/monitoringJob:MonitoringJob <name> <monitoringjob_id>`
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] active: Indicates if the job is active or temporarily disabled.
        :param pulumi.Input[Mapping[str, Any]] config: A configuration dictionary with keys and values depending on the job_type. Configuration details for each job_type are found by submitting a GET request to https://api.nsone.net/v1/monitoring/jobtypes.
        :param pulumi.Input[int] frequency: The frequency, in seconds, at which to run the monitoring job in each region.
        :param pulumi.Input[str] job_type: The type of monitoring job to be run. Refer to the NS1 API documentation (https://ns1.com/api#monitoring-jobs) for supported values which include ping, tcp, dns, http.
        :param pulumi.Input[bool] mute: turn off the notifications for the monitoring job.
        :param pulumi.Input[str] name: The free-form display name for the monitoring job.
        :param pulumi.Input[str] notes: Freeform notes to be included in any notifications about this job.
        :param pulumi.Input[int] notify_delay: The time in seconds after a failure to wait before sending a notification.
        :param pulumi.Input[bool] notify_failback: If true, a notification is sent when a job returns to an "up" state.
        :param pulumi.Input[bool] notify_regional: If true, notifications are sent for any regional failure (and failback if desired), in addition to global state notifications.
        :param pulumi.Input[int] notify_repeat: The time in seconds between repeat notifications of a failed job.
        :param pulumi.Input[str] policy: The policy for determining the monitor's global status
               based on the status of the job in all regions. See NS1 API docs for supported values.
        :param pulumi.Input[bool] rapid_recheck: If true, on any apparent state change, the job is quickly re-run after one second to confirm the state change before notification.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regions: The list of region codes in which to run the monitoring
               job. See NS1 API docs for supported values.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MonitoringJobRuleArgs']]]] rules: A list of rules for determining failure conditions. Each rule acts on one of the outputs from the monitoring job. You must specify key (the output key); comparison (a comparison to perform on the the output); and value (the value to compare to). For example, {"key":"rtt", "comparison":"<", "value":100} is a rule requiring the rtt from a job to be under 100ms, or the job will be marked failed. Available output keys, comparators, and value types are are found by submitting a GET request to https://api.nsone.net/v1/monitoring/jobtypes.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MonitoringJobArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a NS1 Monitoring Job resource. This can be used to create, modify, and delete monitoring jobs.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ns1 as ns1

        uswest_monitor = ns1.MonitoringJob("uswest_monitor",
            name="uswest",
            active=True,
            regions=[
                "lga",
                "sjc",
                "sin",
            ],
            job_type="tcp",
            frequency=60,
            rapid_recheck=True,
            policy="quorum",
            mute=True,
            config={
                "ssl": 1,
                "send": "HEAD / HTTP/1.0\\\\r\\\\n\\\\r\\\\n",
                "port": 443,
                "host": "example-elb-uswest.aws.amazon.com",
            },
            rules=[ns1.MonitoringJobRuleArgs(
                value="200 OK",
                comparison="contains",
                key="output",
            )])
        ```

        ## NS1 Documentation

        [MonitoringJob Api Doc](https://ns1.com/api#monitoring-jobs)

        ## Import

        ```sh
        $ pulumi import ns1:index/monitoringJob:MonitoringJob <name> <monitoringjob_id>`
        ```

        :param str resource_name: The name of the resource.
        :param MonitoringJobArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MonitoringJobArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 active: Optional[pulumi.Input[bool]] = None,
                 config: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 frequency: Optional[pulumi.Input[int]] = None,
                 job_type: Optional[pulumi.Input[str]] = None,
                 mute: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 notes: Optional[pulumi.Input[str]] = None,
                 notify_delay: Optional[pulumi.Input[int]] = None,
                 notify_failback: Optional[pulumi.Input[bool]] = None,
                 notify_list: Optional[pulumi.Input[str]] = None,
                 notify_regional: Optional[pulumi.Input[bool]] = None,
                 notify_repeat: Optional[pulumi.Input[int]] = None,
                 policy: Optional[pulumi.Input[str]] = None,
                 rapid_recheck: Optional[pulumi.Input[bool]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MonitoringJobRuleArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MonitoringJobArgs.__new__(MonitoringJobArgs)

            __props__.__dict__["active"] = active
            if config is None and not opts.urn:
                raise TypeError("Missing required property 'config'")
            __props__.__dict__["config"] = config
            if frequency is None and not opts.urn:
                raise TypeError("Missing required property 'frequency'")
            __props__.__dict__["frequency"] = frequency
            if job_type is None and not opts.urn:
                raise TypeError("Missing required property 'job_type'")
            __props__.__dict__["job_type"] = job_type
            __props__.__dict__["mute"] = mute
            __props__.__dict__["name"] = name
            __props__.__dict__["notes"] = notes
            __props__.__dict__["notify_delay"] = notify_delay
            __props__.__dict__["notify_failback"] = notify_failback
            __props__.__dict__["notify_list"] = notify_list
            __props__.__dict__["notify_regional"] = notify_regional
            __props__.__dict__["notify_repeat"] = notify_repeat
            __props__.__dict__["policy"] = policy
            __props__.__dict__["rapid_recheck"] = rapid_recheck
            if regions is None and not opts.urn:
                raise TypeError("Missing required property 'regions'")
            __props__.__dict__["regions"] = regions
            __props__.__dict__["rules"] = rules
        super(MonitoringJob, __self__).__init__(
            'ns1:index/monitoringJob:MonitoringJob',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            active: Optional[pulumi.Input[bool]] = None,
            config: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            frequency: Optional[pulumi.Input[int]] = None,
            job_type: Optional[pulumi.Input[str]] = None,
            mute: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            notes: Optional[pulumi.Input[str]] = None,
            notify_delay: Optional[pulumi.Input[int]] = None,
            notify_failback: Optional[pulumi.Input[bool]] = None,
            notify_list: Optional[pulumi.Input[str]] = None,
            notify_regional: Optional[pulumi.Input[bool]] = None,
            notify_repeat: Optional[pulumi.Input[int]] = None,
            policy: Optional[pulumi.Input[str]] = None,
            rapid_recheck: Optional[pulumi.Input[bool]] = None,
            regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            rules: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MonitoringJobRuleArgs']]]]] = None) -> 'MonitoringJob':
        """
        Get an existing MonitoringJob resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] active: Indicates if the job is active or temporarily disabled.
        :param pulumi.Input[Mapping[str, Any]] config: A configuration dictionary with keys and values depending on the job_type. Configuration details for each job_type are found by submitting a GET request to https://api.nsone.net/v1/monitoring/jobtypes.
        :param pulumi.Input[int] frequency: The frequency, in seconds, at which to run the monitoring job in each region.
        :param pulumi.Input[str] job_type: The type of monitoring job to be run. Refer to the NS1 API documentation (https://ns1.com/api#monitoring-jobs) for supported values which include ping, tcp, dns, http.
        :param pulumi.Input[bool] mute: turn off the notifications for the monitoring job.
        :param pulumi.Input[str] name: The free-form display name for the monitoring job.
        :param pulumi.Input[str] notes: Freeform notes to be included in any notifications about this job.
        :param pulumi.Input[int] notify_delay: The time in seconds after a failure to wait before sending a notification.
        :param pulumi.Input[bool] notify_failback: If true, a notification is sent when a job returns to an "up" state.
        :param pulumi.Input[bool] notify_regional: If true, notifications are sent for any regional failure (and failback if desired), in addition to global state notifications.
        :param pulumi.Input[int] notify_repeat: The time in seconds between repeat notifications of a failed job.
        :param pulumi.Input[str] policy: The policy for determining the monitor's global status
               based on the status of the job in all regions. See NS1 API docs for supported values.
        :param pulumi.Input[bool] rapid_recheck: If true, on any apparent state change, the job is quickly re-run after one second to confirm the state change before notification.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regions: The list of region codes in which to run the monitoring
               job. See NS1 API docs for supported values.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MonitoringJobRuleArgs']]]] rules: A list of rules for determining failure conditions. Each rule acts on one of the outputs from the monitoring job. You must specify key (the output key); comparison (a comparison to perform on the the output); and value (the value to compare to). For example, {"key":"rtt", "comparison":"<", "value":100} is a rule requiring the rtt from a job to be under 100ms, or the job will be marked failed. Available output keys, comparators, and value types are are found by submitting a GET request to https://api.nsone.net/v1/monitoring/jobtypes.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MonitoringJobState.__new__(_MonitoringJobState)

        __props__.__dict__["active"] = active
        __props__.__dict__["config"] = config
        __props__.__dict__["frequency"] = frequency
        __props__.__dict__["job_type"] = job_type
        __props__.__dict__["mute"] = mute
        __props__.__dict__["name"] = name
        __props__.__dict__["notes"] = notes
        __props__.__dict__["notify_delay"] = notify_delay
        __props__.__dict__["notify_failback"] = notify_failback
        __props__.__dict__["notify_list"] = notify_list
        __props__.__dict__["notify_regional"] = notify_regional
        __props__.__dict__["notify_repeat"] = notify_repeat
        __props__.__dict__["policy"] = policy
        __props__.__dict__["rapid_recheck"] = rapid_recheck
        __props__.__dict__["regions"] = regions
        __props__.__dict__["rules"] = rules
        return MonitoringJob(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def active(self) -> pulumi.Output[Optional[bool]]:
        """
        Indicates if the job is active or temporarily disabled.
        """
        return pulumi.get(self, "active")

    @property
    @pulumi.getter
    def config(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        A configuration dictionary with keys and values depending on the job_type. Configuration details for each job_type are found by submitting a GET request to https://api.nsone.net/v1/monitoring/jobtypes.
        """
        return pulumi.get(self, "config")

    @property
    @pulumi.getter
    def frequency(self) -> pulumi.Output[int]:
        """
        The frequency, in seconds, at which to run the monitoring job in each region.
        """
        return pulumi.get(self, "frequency")

    @property
    @pulumi.getter(name="jobType")
    def job_type(self) -> pulumi.Output[str]:
        """
        The type of monitoring job to be run. Refer to the NS1 API documentation (https://ns1.com/api#monitoring-jobs) for supported values which include ping, tcp, dns, http.
        """
        return pulumi.get(self, "job_type")

    @property
    @pulumi.getter
    def mute(self) -> pulumi.Output[Optional[bool]]:
        """
        turn off the notifications for the monitoring job.
        """
        return pulumi.get(self, "mute")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The free-form display name for the monitoring job.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def notes(self) -> pulumi.Output[Optional[str]]:
        """
        Freeform notes to be included in any notifications about this job.
        """
        return pulumi.get(self, "notes")

    @property
    @pulumi.getter(name="notifyDelay")
    def notify_delay(self) -> pulumi.Output[Optional[int]]:
        """
        The time in seconds after a failure to wait before sending a notification.
        """
        return pulumi.get(self, "notify_delay")

    @property
    @pulumi.getter(name="notifyFailback")
    def notify_failback(self) -> pulumi.Output[Optional[bool]]:
        """
        If true, a notification is sent when a job returns to an "up" state.
        """
        return pulumi.get(self, "notify_failback")

    @property
    @pulumi.getter(name="notifyList")
    def notify_list(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "notify_list")

    @property
    @pulumi.getter(name="notifyRegional")
    def notify_regional(self) -> pulumi.Output[Optional[bool]]:
        """
        If true, notifications are sent for any regional failure (and failback if desired), in addition to global state notifications.
        """
        return pulumi.get(self, "notify_regional")

    @property
    @pulumi.getter(name="notifyRepeat")
    def notify_repeat(self) -> pulumi.Output[Optional[int]]:
        """
        The time in seconds between repeat notifications of a failed job.
        """
        return pulumi.get(self, "notify_repeat")

    @property
    @pulumi.getter
    def policy(self) -> pulumi.Output[Optional[str]]:
        """
        The policy for determining the monitor's global status
        based on the status of the job in all regions. See NS1 API docs for supported values.
        """
        return pulumi.get(self, "policy")

    @property
    @pulumi.getter(name="rapidRecheck")
    def rapid_recheck(self) -> pulumi.Output[Optional[bool]]:
        """
        If true, on any apparent state change, the job is quickly re-run after one second to confirm the state change before notification.
        """
        return pulumi.get(self, "rapid_recheck")

    @property
    @pulumi.getter
    def regions(self) -> pulumi.Output[Sequence[str]]:
        """
        The list of region codes in which to run the monitoring
        job. See NS1 API docs for supported values.
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter
    def rules(self) -> pulumi.Output[Optional[Sequence['outputs.MonitoringJobRule']]]:
        """
        A list of rules for determining failure conditions. Each rule acts on one of the outputs from the monitoring job. You must specify key (the output key); comparison (a comparison to perform on the the output); and value (the value to compare to). For example, {"key":"rtt", "comparison":"<", "value":100} is a rule requiring the rtt from a job to be under 100ms, or the job will be marked failed. Available output keys, comparators, and value types are are found by submitting a GET request to https://api.nsone.net/v1/monitoring/jobtypes.
        """
        return pulumi.get(self, "rules")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetRecordResult',
    'AwaitableGetRecordResult',
    'get_record',
    'get_record_output',
]

@pulumi.output_type
class GetRecordResult:
    """
    A collection of values returned by getRecord.
    """
    def __init__(__self__, answers=None, domain=None, filters=None, id=None, link=None, meta=None, override_ttl=None, regions=None, short_answers=None, tags=None, ttl=None, type=None, use_client_subnet=None, zone=None):
        if answers and not isinstance(answers, list):
            raise TypeError("Expected argument 'answers' to be a list")
        pulumi.set(__self__, "answers", answers)
        if domain and not isinstance(domain, str):
            raise TypeError("Expected argument 'domain' to be a str")
        pulumi.set(__self__, "domain", domain)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if link and not isinstance(link, str):
            raise TypeError("Expected argument 'link' to be a str")
        pulumi.set(__self__, "link", link)
        if meta and not isinstance(meta, dict):
            raise TypeError("Expected argument 'meta' to be a dict")
        pulumi.set(__self__, "meta", meta)
        if override_ttl and not isinstance(override_ttl, bool):
            raise TypeError("Expected argument 'override_ttl' to be a bool")
        pulumi.set(__self__, "override_ttl", override_ttl)
        if regions and not isinstance(regions, list):
            raise TypeError("Expected argument 'regions' to be a list")
        pulumi.set(__self__, "regions", regions)
        if short_answers and not isinstance(short_answers, list):
            raise TypeError("Expected argument 'short_answers' to be a list")
        pulumi.set(__self__, "short_answers", short_answers)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)
        if ttl and not isinstance(ttl, int):
            raise TypeError("Expected argument 'ttl' to be a int")
        pulumi.set(__self__, "ttl", ttl)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if use_client_subnet and not isinstance(use_client_subnet, bool):
            raise TypeError("Expected argument 'use_client_subnet' to be a bool")
        pulumi.set(__self__, "use_client_subnet", use_client_subnet)
        if zone and not isinstance(zone, str):
            raise TypeError("Expected argument 'zone' to be a str")
        pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter
    def answers(self) -> Sequence['outputs.GetRecordAnswerResult']:
        """
        List of NS1 answers.
        """
        return pulumi.get(self, "answers")

    @property
    @pulumi.getter
    def domain(self) -> str:
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter
    def filters(self) -> Sequence['outputs.GetRecordFilterResult']:
        """
        List of NS1 filters.
        """
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def link(self) -> str:
        """
        The target record this links to.
        """
        return pulumi.get(self, "link")

    @property
    @pulumi.getter
    def meta(self) -> Mapping[str, Any]:
        """
        Map of metadata
        """
        return pulumi.get(self, "meta")

    @property
    @pulumi.getter(name="overrideTtl")
    def override_ttl(self) -> bool:
        return pulumi.get(self, "override_ttl")

    @property
    @pulumi.getter
    def regions(self) -> Sequence['outputs.GetRecordRegionResult']:
        """
        List of regions.
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter(name="shortAnswers")
    def short_answers(self) -> Sequence[str]:
        return pulumi.get(self, "short_answers")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, Any]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def ttl(self) -> int:
        """
        The records' time to live (in seconds).
        """
        return pulumi.get(self, "ttl")

    @property
    @pulumi.getter
    def type(self) -> str:
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="useClientSubnet")
    def use_client_subnet(self) -> bool:
        """
        Whether to use EDNS client subnet data when available (in filter chain).
        """
        return pulumi.get(self, "use_client_subnet")

    @property
    @pulumi.getter
    def zone(self) -> str:
        return pulumi.get(self, "zone")


class AwaitableGetRecordResult(GetRecordResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRecordResult(
            answers=self.answers,
            domain=self.domain,
            filters=self.filters,
            id=self.id,
            link=self.link,
            meta=self.meta,
            override_ttl=self.override_ttl,
            regions=self.regions,
            short_answers=self.short_answers,
            tags=self.tags,
            ttl=self.ttl,
            type=self.type,
            use_client_subnet=self.use_client_subnet,
            zone=self.zone)


def get_record(domain: Optional[str] = None,
               type: Optional[str] = None,
               zone: Optional[str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRecordResult:
    """
    Provides details about a NS1 Record. Use this if you would simply like to read
    information from NS1 into your configurations. For read/write operations, you
    should use a resource.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ns1 as ns1

    # Get details about a NS1 Record.
    example = ns1.get_record(zone="example.io",
        domain="terraform.example.io",
        type="A")
    ```


    :param str domain: The records' domain.
    :param str type: The records' RR type.
    :param str zone: The zone the record belongs to.
    """
    __args__ = dict()
    __args__['domain'] = domain
    __args__['type'] = type
    __args__['zone'] = zone
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ns1:index/getRecord:getRecord', __args__, opts=opts, typ=GetRecordResult).value

    return AwaitableGetRecordResult(
        answers=pulumi.get(__ret__, 'answers'),
        domain=pulumi.get(__ret__, 'domain'),
        filters=pulumi.get(__ret__, 'filters'),
        id=pulumi.get(__ret__, 'id'),
        link=pulumi.get(__ret__, 'link'),
        meta=pulumi.get(__ret__, 'meta'),
        override_ttl=pulumi.get(__ret__, 'override_ttl'),
        regions=pulumi.get(__ret__, 'regions'),
        short_answers=pulumi.get(__ret__, 'short_answers'),
        tags=pulumi.get(__ret__, 'tags'),
        ttl=pulumi.get(__ret__, 'ttl'),
        type=pulumi.get(__ret__, 'type'),
        use_client_subnet=pulumi.get(__ret__, 'use_client_subnet'),
        zone=pulumi.get(__ret__, 'zone'))


@_utilities.lift_output_func(get_record)
def get_record_output(domain: Optional[pulumi.Input[str]] = None,
                      type: Optional[pulumi.Input[str]] = None,
                      zone: Optional[pulumi.Input[str]] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetRecordResult]:
    """
    Provides details about a NS1 Record. Use this if you would simply like to read
    information from NS1 into your configurations. For read/write operations, you
    should use a resource.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ns1 as ns1

    # Get details about a NS1 Record.
    example = ns1.get_record(zone="example.io",
        domain="terraform.example.io",
        type="A")
    ```


    :param str domain: The records' domain.
    :param str type: The records' RR type.
    :param str zone: The zone the record belongs to.
    """
    ...
